@@ -22,6 +22,7 @@ from sklearn.preprocessing import StandardScaler,MinMaxScaler
 from blobcity.utils import get_dataframe_type,Progress,write_dataframe
 from blobcity.code_gen import code_generator
 import yaml
+
 """
 Python file consists of Class Model to initialize/store and retrive data associated to trained machine learning model.
 """
@@ -232,6 +233,9 @@ class Model:
             plt.figure(figsize = (12, 6))
             plt.barh(range(len(val)), list(val.values()), align='center')
             plt.yticks(range(len(val)),list(val.keys()))
+            plt.xlabel("Importance")
+            plt.ylabel("Feature")
+            plt.tight_layout()
             plt.show()
         else:
             print("Feature importance not available for dataset with less then 2 columns") 
@@ -285,4 +289,4 @@ class Model:
                 elif abs(n_rows)>len(self.plot_data[0]):
                     raise ValueError("entered row counts {} more than actual row counts {}".format(abs(len(self.plot_data[0])-abs(n_rows)),len(self.plot_data[0])))
             else:
-                raise ValueError("Number of rows can't be Zero")
\ No newline at end of file
+                raise ValueError("Number of rows can't be Zero")
